@@ -7,13 +7,12 @@
 """
 
 __author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
-__version__ = "$Revision: 8 $"
-__date__ = "$Date: 2010/02/25 $"
+__version__ = "$Revision: 9 $"
+__date__ = "$Date: 2010/04/04 $"
 __copyright__ = ""
 __license__ = "GPLv2"
 
 
-import sys
 import xmlrpclib
 import urllib2
 import os
@@ -23,11 +22,11 @@ import socket
 
 from ldm.Message import Message
 from ldm.Account import Account
+from ldm.SqlDriver import TIME_FORMAT
 from ProxyedTransp import ProxyedTransp
 from Service import Service
 from ScriboExc import XmlrpcExc, SocketExc
 
-LJ_TIME_FORMAT = r"%Y-%m-%d %H:%M:%S"
 MAX_EVENTS = 50
 MAX_SKIP = 100
 MAX_ITEMS = 50
@@ -179,12 +178,18 @@ class LivejAccount(Account, Service):
 
         urllib2.install_opener(self._opener)
 
-
         self.initialized = True
 
 
-    def exec_xmlrpc(self, funct, param):
+    def disconnect(self):
 
+        self.initialized = False
+
+
+    def exec_xmlrpc(self, funct, param):
+        """
+        execute XML-RPc query, return result and convert for errors
+        """
         self.connect()
 
         param.update({
@@ -295,7 +300,7 @@ class LivejAccount(Account, Service):
         @return None
         """
 
-        moment = time.strptime(msg.date, LJ_TIME_FORMAT)
+        moment = time.strptime(msg.date, TIME_FORMAT)
 
         if not msg.tags:
             msg.tags = ''
@@ -344,12 +349,8 @@ class LivejAccount(Account, Service):
         """
         Convert response from LJ to utf-8. sqlite3 need utf-8 strings
         """
-        if type(lj_field) == str:
-            return lj_field.decode('utf-8')
-        elif type(lj_field) == int or type(lj_field) == float:
-            return unicode(lj_field)
-        else:
-            return lj_field.data.decode('utf-8')
+
+        return str(lj_field).decode('utf-8')
 
 
     def _parse_post(self, lj_post, new_post=None):
@@ -512,11 +513,11 @@ class LivejAccount(Account, Service):
 
         # add 1 second to date
         last_sync = result[-1]['time']
-        last_sync = time.strptime(last_sync, LJ_TIME_FORMAT)
+        last_sync = time.strptime(last_sync, TIME_FORMAT)
         last_sync = time.mktime(last_sync)
         last_sync = last_sync + 1
         last_sync = time.localtime(last_sync)
-        last_sync = time.strftime(LJ_TIME_FORMAT, last_sync)
+        last_sync = time.strftime(TIME_FORMAT, last_sync)
 
         #self.set_option('posts_last', last_sync)
         self.date = last_sync
@@ -587,7 +588,7 @@ class LivejAccount(Account, Service):
         result = self.exec_xmlrpc('getfriends', param)
 
         #parse result from server
-        self.friends = []
+        self.friends_list = []
         old_friends = self.get_option('friends')
         new_friends = []
         has_new = False
@@ -735,7 +736,8 @@ class LivejAccount(Account, Service):
         param['add'] = ({'username': user.username},)
 
         try:
-            result = self.exec_xmlrpc('editfriends', param)
+            # Note: editfriends return result
+            self.exec_xmlrpc('editfriends', param)
         except xmlrpclib.Fault:
             return False
 
