@@ -39,10 +39,10 @@ class TreeMessage(ToolbarWindow):
         self.tree_view = self.tree_view_com(msg)
         self.create_actions()
         toolbar = self.create_toolbar()
-        self.vbox = QtGui.QVBoxLayout()
+        self.vbox = QtGui.QHBoxLayout()
         self.vbox.addWidget(toolbar)
         self.vbox.addWidget(self.tree_view)
-        self.setLayout(self.vbox)
+        self.setLayout(self.hbox)
 
 
     def tree_view_com(self, msg):
@@ -57,17 +57,13 @@ class TreeMessage(ToolbarWindow):
 
     def create_toolbar(self):
         """
-        create toolbar for window
+        create profile for "add profile" window
         @return
         """
-        file_tool_bar = QtGui.QToolBar("", self)
-        file_tool_bar.setIconSize(QtCore.QSize(64, 64))
-        file_tool_bar.addAction(self.back_act)
-        file_tool_bar.addAction(self.home_act)
+        file_tool_bar = super(AddPostWindow, self).create_toolbar()
         file_tool_bar.addAction(self.refresh_act)
         return file_tool_bar
 
-
     def create_actions(self):
         """
         create buttons for toolbar
